

set -ex



pip check
rio --help
rio info /var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/abs_c8c9148a-4239-49c5-9b5a-3b5432739ede_t7sw2zj/clone/recipe/test_data/test.tif
$PYTHON -m pytest -v -m "not wheel" -rxXs -k "not (test_target_aligned_pixels or test_reproject_error_propagation or test_outer_boundless_pixel_fidelity)" tests
exit 0
